<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\AMLI\BudgetBundle\Controller;

use Chill\AMLI\BudgetBundle\Calculator\CalculatorManager;
use Chill\AMLI\BudgetBundle\Entity\Charge;
use Chill\AMLI\BudgetBundle\Entity\Resource;
use Chill\AMLI\BudgetBundle\Security\Authorization\BudgetElementVoter;
use Chill\PersonBundle\Entity\Person;
use DateTime;
use Doctrine\ORM\EntityManagerInterface;
use Psr\Log\LoggerInterface;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Contracts\Translation\TranslatorInterface;

use function array_merge;
use function count;

class ElementController extends Controller
{
    /**
     * @var CalculatorManager
     */
    protected $calculator;

    /**
     * @var LoggerInterface
     */
    protected $chillMainLogger;

    /**
     * @var EntityManagerInterface
     */
    protected $em;

    /**
     * @var TranslatorInterface
     */
    protected $translator;

    public function __construct(
        EntityManagerInterface $em,
        TranslatorInterface $translator,
        LoggerInterface $chillMainLogger,
        CalculatorManager $calculator
    ) {
        $this->em = $em;
        $this->translator = $translator;
        $this->chillMainLogger = $chillMainLogger;
        $this->calculator = $calculator;
    }

    /**
     * @Route(
     *     "{_locale}/budget/elements/by-person/{id}",
     *     name="chill_budget_elements_index"
     * )
     */
    public function indexAction(Person $person)
    {
        $this->denyAccessUnlessGranted(BudgetElementVoter::SHOW, $person);

        $charges = $this->em
            ->getRepository(Charge::class)
            ->findByPerson($person);
        $ressources = $this->em
            ->getRepository(Resource::class)
            ->findByPerson($person);

        $now = new DateTime('now');

        $actualCharges = $this->em
            ->getRepository(Charge::class)
            ->findByPersonAndDate($person, $now);
        $actualResources = $this->em
            ->getRepository(Resource::class)
            ->findByPersonAndDate($person, $now);

        $elements = array_merge($actualCharges, $actualResources);

        if (count($elements) > 0) {
            $results = $this->calculator->calculateDefault($elements);
        }

        return $this->render('ChillAMLIBudgetBundle:Element:index.html.twig', [
            'person' => $person,
            'charges' => $charges,
            'resources' => $ressources,
            'results' => $results ?? [],
        ]);
    }
}
