<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\AMLI\BudgetBundle\Controller;

use Chill\AMLI\BudgetBundle\Entity\Resource;
use Chill\AMLI\BudgetBundle\Form\ResourceType;
use Chill\PersonBundle\Entity\Person;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Symfony\Component\HttpFoundation\Request;

class ResourceController extends AbstractElementController
{
    /**
     * @Route(
     *     "{_locale}/budget/resource/{id}/delete",
     *     name="chill_budget_resource_delete"
     * )
     *
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function deleteAction(Request $request, Resource $resource)
    {
        return $this->_delete(
            $resource,
            $request,
            '@ChillAMLIBudget/Resource/confirm_delete.html.twig',
            'Resource deleted'
        );
    }

    /**
     * @Route(
     *     "{_locale}/budget/resource/{id}/edit",
     *     name="chill_budget_resource_edit"
     * )
     *
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function editAction(Request $request, Resource $resource)
    {
        return $this->_edit(
            $resource,
            $request,
            '@ChillAMLIBudget/Resource/edit.html.twig',
            'Resource updated'
        );
    }

    /**
     * @Route(
     *     "{_locale}/budget/resource/by-person/{id}/new",
     *     name="chill_budget_resource_new"
     * )
     *
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function newAction(Request $request, Person $person)
    {
        return $this->_new(
            $person,
            $request,
            '@ChillAMLIBudget/Resource/new.html.twig',
            'Resource created'
        );
    }

    /**
     * @Route(
     *     "{_locale}/budget/resource/{id}/view",
     *     name="chill_budget_resource_view"
     * )
     *
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function viewAction(Resource $resource)
    {
        return $this->_view($resource, '@ChillAMLIBudget/Resource/view.html.twig');
    }

    protected function createNewElement()
    {
        return new Resource();
    }

    protected function getType()
    {
        return ResourceType::class;
    }
}
