<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\AMLI\BudgetBundle\Security\Authorization;

use Chill\AMLI\BudgetBundle\Entity\AbstractElement;
use Chill\MainBundle\Entity\User;
use Chill\MainBundle\Security\Authorization\AbstractChillVoter;
use Chill\MainBundle\Security\Authorization\AuthorizationHelper;
use Chill\MainBundle\Security\ProvideRoleHierarchyInterface;
use Chill\PersonBundle\Entity\Person;
use Symfony\Component\Security\Core\Role\Role;

use function in_array;

class BudgetElementVoter extends AbstractChillVoter implements ProvideRoleHierarchyInterface
{
    public const CREATE = 'CHILL_BUDGET_ELEMENT_CREATE';

    public const DELETE = 'CHILL_BUDGET_ELEMENT_DELETE';

    public const ROLES = [
        self::CREATE,
        self::DELETE,
        self::SHOW,
        self::UPDATE,
    ];

    public const SHOW = 'CHILL_BUDGET_ELEMENT_SHOW';

    public const UPDATE = 'CHILL_BUDGET_ELEMENT_UPDATE';

    /**
     * @var AuthorizationHelper
     */
    protected $authorizationHelper;

    public function __construct(AuthorizationHelper $authorizationHelper)
    {
        $this->authorizationHelper = $authorizationHelper;
    }

    public function getRoles(): array
    {
        return self::ROLES;
    }

    public function getRolesWithHierarchy(): array
    {
        return ['Budget elements' => self::ROLES];
    }

    public function getRolesWithoutScope(): array
    {
        return self::ROLES;
    }

    protected function supports($attribute, $subject)
    {
        return (in_array($attribute, self::ROLES, true) && $subject instanceof AbstractElement)
                || ($subject instanceof Person && in_array($attribute, [self::SHOW, self::CREATE], true));
    }

    protected function voteOnAttribute($attribute, $subject, \Symfony\Component\Security\Core\Authentication\Token\TokenInterface $token)
    {
        $user = $token->getUser();

        if (false === $user instanceof User) {
            return false;
        }

        return $this->authorizationHelper
            ->userHasAccess($user, $subject, new Role($attribute));
    }
}
