<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\CalendarBundle\Menu;

use Chill\MainBundle\Routing\LocalMenuBuilderInterface;
use Chill\MainBundle\Security\Authorization\AuthorizationHelper;
use Chill\PersonBundle\Entity\AccompanyingPeriod;
use Knp\Menu\MenuItem;
use Symfony\Component\Security\Core\Authentication\Token\Storage\TokenStorageInterface;
use Symfony\Contracts\Translation\TranslatorInterface;

class AccompanyingCourseMenuBuilder implements LocalMenuBuilderInterface
{
    protected AuthorizationHelper $authorizationHelper;

    protected TokenStorageInterface $tokenStorage;

    protected TranslatorInterface $translator;

    public function __construct(
        TokenStorageInterface $tokenStorage,
        AuthorizationHelper $authorizationHelper,
        TranslatorInterface $translator
    ) {
        $this->translator = $translator;
        $this->authorizationHelper = $authorizationHelper;
        $this->tokenStorage = $tokenStorage;
    }

    public function buildMenu($menuId, MenuItem $menu, array $parameters)
    {
        $period = $parameters['accompanyingCourse'];

        if (AccompanyingPeriod::STEP_DRAFT !== $period->getStep()) {
            $menu->addChild($this->translator->trans('Calendar'), [
                'route' => 'chill_calendar_calendar_list',
                'routeParameters' => [
                    'accompanying_period_id' => $period->getId(),
                ], ])
                ->setExtras(['order' => 35]);
        }
    }

    public static function getMenuIds(): array
    {
        return ['accompanyingCourse'];
    }
}
