<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\DocGeneratorBundle\Context;

use Chill\DocGeneratorBundle\Context\Exception\ContextNotFoundException;
use Chill\DocGeneratorBundle\Entity\DocGeneratorTemplate;

class ContextManager
{
    /**
     * @var DocGeneratorContextInterface[]|iterable
     */
    private iterable $contexts;

    public function __construct(iterable $contexts)
    {
        $this->contexts = $contexts;
    }

    /**
     * @throw ContextNotFoundException when the context is not  found
     */
    public function getContextByDocGeneratorTemplate(DocGeneratorTemplate $docGeneratorTemplate): DocGeneratorContextInterface
    {
        foreach ($this->contexts as $key => $context) {
            if ($docGeneratorTemplate->getContext() === $key) {
                return $context;
            }
        }

        throw new ContextNotFoundException($docGeneratorTemplate->getContext());
    }

    public function getContextByKey(string $searchedKey): DocGeneratorContextInterface
    {
        foreach ($this->contexts as $key => $context) {
            if ($searchedKey === $key) {
                return $context;
            }
        }

        throw new ContextNotFoundException($searchedKey);
    }

    public function getContexts(): array
    {
        return iterator_to_array($this->contexts);
    }
}
