<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Workflow\Templating;

use Chill\MainBundle\Entity\Workflow\EntityWorkflow;
use Chill\MainBundle\Repository\Workflow\EntityWorkflowRepository;
use Chill\MainBundle\Workflow\EntityWorkflowManager;
use Chill\MainBundle\Workflow\Helper\MetadataExtractor;
use Symfony\Component\Serializer\Normalizer\NormalizerInterface;
use Symfony\Component\Workflow\Registry;
use Symfony\Component\Workflow\Transition;
use Twig\Environment;
use Twig\Extension\RuntimeExtensionInterface;

class WorkflowTwigExtensionRuntime implements RuntimeExtensionInterface
{
    private EntityWorkflowManager $entityWorkflowManager;

    private MetadataExtractor $metadataExtractor;

    private NormalizerInterface $normalizer;

    private Registry $registry;

    private EntityWorkflowRepository $repository;

    public function __construct(
        EntityWorkflowManager $entityWorkflowManager,
        Registry $registry,
        EntityWorkflowRepository $repository,
        MetadataExtractor $metadataExtractor,
        NormalizerInterface $normalizer
    ) {
        $this->entityWorkflowManager = $entityWorkflowManager;
        $this->registry = $registry;
        $this->repository = $repository;
        $this->metadataExtractor = $metadataExtractor;
        $this->normalizer = $normalizer;
    }

    public function getTransitionByString(EntityWorkflow $entityWorkflow, string $key): ?Transition
    {
        $workflow = $this->registry->get($entityWorkflow, $entityWorkflow->getWorkflowName());
        $transitions = $workflow->getDefinition()->getTransitions();

        foreach ($transitions as $transition) {
            if ($transition->getName() === $key) {
                return $transition;
            }
        }

        return null;
    }

    public function listWorkflows(Environment $environment, string $relatedEntityClass, int $relatedEntityId, array $options = []): string
    {
        $blankEntityWorkflow = new EntityWorkflow();
        $blankEntityWorkflow
            ->setRelatedEntityId($relatedEntityId)
            ->setRelatedEntityClass($relatedEntityClass);

        $workflowsList = $this->metadataExtractor->availableWorkflowFor($relatedEntityClass, $relatedEntityId);

        // get the related entity already created
        $entityWorkflows = [];

        foreach ($entityWorkflowsNaked = $this->repository->findBy(
            ['relatedEntityClass' => $relatedEntityClass, 'relatedEntityId' => $relatedEntityId]
        ) as $entityWorkflow) {
            $workflow = $this->registry->get($entityWorkflow, $entityWorkflow->getWorkflowName());
            $entityWorkflows[] = [
                'entity_workflow' => $entityWorkflow,
                'workflow' => $this->metadataExtractor->buildArrayPresentationForWorkflow($workflow),
                'handler' => $this->entityWorkflowManager->getHandler($entityWorkflow),
            ];
        }

        return $environment->render('@ChillMain/Workflow/_extension_list_workflow_for.html.twig', [
            'entity_workflows_json' => $this->normalizer->normalize($entityWorkflowsNaked, 'json', ['groups' => 'read']),
            'entity_workflows' => $entityWorkflows,
            'blank_workflow' => $blankEntityWorkflow,
            'workflows_availables' => $workflowsList,
        ]);
    }
}
