<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Form;

use Chill\MainBundle\Form\Event\CustomizeFormEvent;
use Chill\MainBundle\Form\Type\ChillDateType;
use Chill\MainBundle\Form\Type\PickCenterType;
use Chill\PersonBundle\Config\ConfigPersonAltNamesHelper;
use Chill\PersonBundle\Entity\Person;
use Chill\PersonBundle\Form\Type\GenderType;
use Chill\PersonBundle\Form\Type\PersonAltNameType;
use Chill\PersonBundle\Security\Authorization\PersonVoter;
use Symfony\Component\DependencyInjection\ParameterBag\ParameterBagInterface;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\EmailType;
use Symfony\Component\Form\Extension\Core\Type\TelType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

final class CreationPersonType extends AbstractType
{
    // TODO: This is only used in test.
    // TODO: See if this is still valid and update accordingly.
    public const NAME = 'chill_personbundle_person_creation';

    private bool $askCenters;

    private ConfigPersonAltNamesHelper $configPersonAltNamesHelper;

    private EventDispatcherInterface $dispatcher;

    public function __construct(
        ConfigPersonAltNamesHelper $configPersonAltNamesHelper,
        EventDispatcherInterface $dispatcher,
        ParameterBagInterface $parameterBag
    ) {
        $this->configPersonAltNamesHelper = $configPersonAltNamesHelper;
        $this->dispatcher = $dispatcher;
        $this->askCenters = $parameterBag->get('chill_main')['acl']['form_show_centers'];
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('firstName')
            ->add('lastName')
            ->add('gender', GenderType::class, [
                'required' => true, 'placeholder' => null,
            ])
            ->add('birthdate', ChillDateType::class, [
                'required' => false,
            ])
            ->add('phonenumber', TelType::class, [
                'required' => false,
            ])
            ->add('mobilenumber', TelType::class, [
                'required' => false,
            ])
            ->add('email', EmailType::class, [
                'required' => false,
            ]);

        if ($this->askCenters) {
            $builder
                ->add('center', PickCenterType::class, [
                    'required' => false,
                    'role' => PersonVoter::CREATE,
                ]);
        }

        if ($this->configPersonAltNamesHelper->hasAltNames()) {
            $builder->add('altNames', PersonAltNameType::class, [
                'by_reference' => false,
            ]);
        }

        $this->dispatcher->dispatch(
            new CustomizeFormEvent(self::class, $builder),
            CustomizeFormEvent::NAME
        );
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults([
            'data_class' => Person::class,
        ]);
    }

    /**
     * @return string
     */
    public function getBlockPrefix()
    {
        return self::NAME;
    }
}
