<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Tests\Serializer\Normalizer;

use Chill\PersonBundle\Entity\Household\Household;
use Chill\PersonBundle\Entity\Household\HouseholdMember;
use Chill\PersonBundle\Entity\Household\Position;
use Chill\PersonBundle\Entity\Person;
use DateTimeImmutable;
use Symfony\Bundle\FrameworkBundle\Test\KernelTestCase;
use Symfony\Component\Serializer\Normalizer\NormalizerInterface;

/**
 * @internal
 * @coversNothing
 */
final class HouseholdNormalizerTest extends KernelTestCase
{
    private ?NormalizerInterface $normalizer;

    protected function setUp(): void
    {
        self::bootKernel();
        $this->normalizer = self::$container->get(NormalizerInterface::class);
    }

    public function testNormalizationRecursive()
    {
        $person = new Person();
        $member = new HouseholdMember();
        $household = new Household();
        $position = (new Position())
            ->setShareHousehold(true)
            ->setAllowHolder(true);

        $member->setPerson($person)
            ->setStartDate(new DateTimeImmutable('1 year ago'))
            ->setEndDate(new DateTimeImmutable('1 month ago'));

        $household->addMember($member);

        $normalized = $this->normalizer->normalize(
            $household,
            'json',
            ['groups' => ['read']]
        );

        $this->assertIsArray($normalized);
        $this->assertArrayHasKey('type', $normalized);
        $this->assertEquals('household', $normalized['type']);
    }
}
