<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Workflow;

use Chill\MainBundle\Entity\Workflow\EntityWorkflow;
use Chill\MainBundle\Workflow\EntityWorkflowHandlerInterface;
use Chill\PersonBundle\Entity\AccompanyingPeriod\AccompanyingPeriodWork;
use Chill\PersonBundle\Repository\AccompanyingPeriod\AccompanyingPeriodWorkRepository;

class AccompanyingPeriodWorkWorkflowHandler implements EntityWorkflowHandlerInterface
{
    private AccompanyingPeriodWorkRepository $repository;

    public function __construct(AccompanyingPeriodWorkRepository $repository)
    {
        $this->repository = $repository;
    }

    public function getRelatedEntity(EntityWorkflow $entityWorkflow): ?object
    {
        return $this->repository->find($entityWorkflow->getRelatedEntityId());
    }

    public function getRoleShow(EntityWorkflow $entityWorkflow): ?string
    {
        return null;
    }

    public function getTemplate(EntityWorkflow $entityWorkflow, array $options = []): string
    {
        return '@ChillPerson/Workflow/_accompanying_period_work.html.twig';
    }

    public function getTemplateData(EntityWorkflow $entityWorkflow, array $options = []): array
    {
        return [
            'entity_workflow' => $entityWorkflow,
            'work' => $this->getRelatedEntity($entityWorkflow),
        ];
    }

    public function getTemplateTitle(EntityWorkflow $entityWorkflow, array $options = []): string
    {
        return '@ChillPerson/Workflow/_accompanying_period_work.title.html.twig';
    }

    public function getTemplateTitleData(EntityWorkflow $entityWorkflow, array $options = []): array
    {
        return $this->getTemplateData($entityWorkflow, $options);
    }

    public function supports(EntityWorkflow $entityWorkflow, array $options = []): bool
    {
        return $entityWorkflow->getRelatedEntityClass() === AccompanyingPeriodWork::class;
    }

    public function supportsFreeze(EntityWorkflow $entityWorkflow, array $options = []): bool
    {
        return false;
    }
}
